@@ -1,4 +1,16 @@
 use super::*;
+use std::fmt::Debug;
+
+impl Debug for WindowSize {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("WindowSize")
+            .field("width", &self.width())
+            .field("height", &self.height())
+            .field("aspect_radio", &self.aspect_radio())
+            .field("listen_window", &self.listen_window.is_some())
+            .finish()
+    }
+}
 
 impl Display for WindowSize {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
