@@ -1,21 +1,29 @@
+mod builder;
 #[deny(missing_doc_code_examples)]
 mod display;
-mod window_size;
+mod methods;
 
+pub use self::builder::UseWindowBuilder;
+use self::builder::WindowSizeData;
 use dioxus::core::ScopeState;
 use gloo_events::EventListener;
+use log::{info};
 use std::{
+    cell::RefCell,
     fmt::{Display, Formatter},
     marker::PhantomData,
+    rc::Rc,
 };
+use wasm_bindgen::JsValue;
 use web_sys::window;
 
+const MISSING_W: f64 = 375.0;
+const MISSING_H: f64 = 812.0;
+
 /// Window size effect handler
-#[derive(Debug)]
 pub struct WindowSize {
-    x: f64,
-    y: f64,
-    listener: Option<EventListener>,
+    data: Rc<RefCell<WindowSizeData>>,
+    listen_window: Option<EventListener>,
 }
 
 /// hooks for window's size
@@ -24,7 +32,7 @@ pub struct WindowSize {
 ///
 /// * `cx`: [`Scope`] or [`ScopeState`]
 ///
-/// returns: WindowSize
+/// returns: [`WindowSize`]
 ///
 /// # Examples
 ///
@@ -40,8 +48,9 @@ pub struct WindowSize {
 ///     ))
 /// }
 /// ```
-pub fn use_window_size(cx: &ScopeState) -> WindowSize {
-    WindowSize::new(&cx).unwrap()
+#[inline]
+pub fn use_window_size(cx: &ScopeState) -> &mut WindowSize {
+    UseWindowBuilder::default().use_window_size(cx)
 }
 
 /// Window layout effect handler
@@ -51,34 +60,37 @@ pub struct WindowLayout<T> {
     bound: PhantomData<T>,
 }
 
-
 /// hooks for window's layout
 ///
 /// # Arguments
 ///
 /// * `cx`: [`Scope`] or [`ScopeState`]
 ///
-/// returns: WindowLayout<T>
+/// returns: [`WindowLayout`]
 ///
 /// # Examples
 ///
 /// ```
 /// use dioxus::prelude::*;
-/// use dioxus_use_window::use_window_layout;
+/// use dioxus_use_window::{use_window_layout, ResponsiveLayout};
 ///
 /// fn App(cx: Scope) -> Element {
-///     let layout = use_window_layout(&cx);
+///     let layout = use_window_layout::<ResponsiveLayout>(&cx);
 ///
 ///     cx.render(rsx!(
 ///         h1 { "Window layout: {layout}" }
 ///     ))
 /// }
 /// ```
-pub fn use_window_layout<T>(cx: &ScopeState) -> WindowLayout<T>
-    where
-        T: From<usize>,
+pub fn use_window_layout<T>(cx: &ScopeState) -> &WindowLayout<T>
+where
+    T: From<usize>,
+    T: 'static,
 {
-    WindowLayout { inner: WindowSize::new(cx).unwrap(), bound: Default::default() }
+    cx.use_hook(|_| WindowLayout {
+        inner: WindowSize::new(cx, MISSING_W, MISSING_H).unwrap_or_default(),
+        bound: Default::default(),
+    })
 }
 
 /// Window width effect handler
@@ -87,7 +99,6 @@ pub struct WindowWidth {
     inner: WindowSize,
 }
 
-
 /// hooks for window's width
 ///
 /// # Arguments
@@ -110,8 +121,8 @@ pub struct WindowWidth {
 ///     ))
 /// }
 /// ```
-pub fn use_width(cx: &ScopeState) -> WindowWidth {
-    WindowWidth { inner: WindowSize::new(cx).unwrap() }
+pub fn use_width(cx: &ScopeState) -> &WindowWidth {
+    cx.use_hook(|_| WindowWidth { inner: WindowSize::new(cx, MISSING_W, MISSING_H).unwrap_or_default() })
 }
 
 /// Window height effect handler
@@ -120,7 +131,6 @@ pub struct WindowHeight {
     inner: WindowSize,
 }
 
-
 /// hooks for window's height
 ///
 /// # Arguments
@@ -136,13 +146,13 @@ pub struct WindowHeight {
 /// use dioxus_use_window::use_height;
 ///
 /// fn App(cx: Scope) -> Element {
-///     let heigh = use_height(&cx);
+///     let height = use_height(&cx);
 ///
 ///     cx.render(rsx!(
-///         h1 { "Window height: {heigh}" }
+///         h1 { "Window height: {height}" }
 ///     ))
 /// }
 /// ```
-pub fn use_height(cx: &ScopeState) -> WindowHeight {
-    WindowHeight { inner: WindowSize::new(cx).unwrap() }
+pub fn use_height(cx: &ScopeState) -> &WindowHeight {
+    cx.use_hook(|_| WindowHeight { inner: WindowSize::new(cx, MISSING_W, MISSING_H).unwrap_or_default() })
 }
